==> istio-model-v1alpha3-6.6.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/VirtualServiceSpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;

 /**
  * Generated
  */
public interface VirtualServiceSpecFluent<A extends VirtualServiceSpecFluent<A>> extends Fluent<A>{
  public A addToExportTo(Integer index,String item);
  public A setToExportTo(Integer index,String item);
  public A addToExportTo(java.lang.String... items);
  public A addAllToExportTo(Collection<String> items);
  public A removeFromExportTo(java.lang.String... items);
  public A removeAllFromExportTo(Collection<String> items);
  public List<String> getExportTo();
  public String getExportTo(Integer index);
  public String getFirstExportTo();
  public String getLastExportTo();
  public String getMatchingExportTo(Predicate<String> predicate);
  public Boolean hasMatchingExportTo(Predicate<String> predicate);
  public A withExportTo(List<String> exportTo);
  public A withExportTo(java.lang.String... exportTo);
  public Boolean hasExportTo();
  public A addToGateways(Integer index,String item);
  public A setToGateways(Integer index,String item);
  public A addToGateways(java.lang.String... items);
  public A addAllToGateways(Collection<String> items);
  public A removeFromGateways(java.lang.String... items);
  public A removeAllFromGateways(Collection<String> items);
  public List<String> getGateways();
  public String getGateway(Integer index);
  public String getFirstGateway();
  public String getLastGateway();
  public String getMatchingGateway(Predicate<String> predicate);
  public Boolean hasMatchingGateway(Predicate<String> predicate);
  public A withGateways(List<String> gateways);
  public A withGateways(java.lang.String... gateways);
  public Boolean hasGateways();
  public A addToHosts(Integer index,String item);
  public A setToHosts(Integer index,String item);
  public A addToHosts(java.lang.String... items);
  public A addAllToHosts(Collection<String> items);
  public A removeFromHosts(java.lang.String... items);
  public A removeAllFromHosts(Collection<String> items);
  public List<String> getHosts();
  public String getHost(Integer index);
  public String getFirstHost();
  public String getLastHost();
  public String getMatchingHost(Predicate<String> predicate);
  public Boolean hasMatchingHost(Predicate<String> predicate);
  public A withHosts(List<String> hosts);
  public A withHosts(java.lang.String... hosts);
  public Boolean hasHosts();
  public A addToHttp(Integer index,HTTPRoute item);
  public A setToHttp(Integer index,HTTPRoute item);
  public A addToHttp(io.fabric8.istio.api.networking.v1alpha3.HTTPRoute... items);
  public A addAllToHttp(Collection<HTTPRoute> items);
  public A removeFromHttp(io.fabric8.istio.api.networking.v1alpha3.HTTPRoute... items);
  public A removeAllFromHttp(Collection<HTTPRoute> items);
  public A removeMatchingFromHttp(Predicate<HTTPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHttp instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRoute> getHttp();
  public List<HTTPRoute> buildHttp();
  public HTTPRoute buildHttp(Integer index);
  public HTTPRoute buildFirstHttp();
  public HTTPRoute buildLastHttp();
  public HTTPRoute buildMatchingHttp(Predicate<HTTPRouteBuilder> predicate);
  public Boolean hasMatchingHttp(Predicate<HTTPRouteBuilder> predicate);
  public A withHttp(List<HTTPRoute> http);
  public A withHttp(io.fabric8.istio.api.networking.v1alpha3.HTTPRoute... http);
  public Boolean hasHttp();
  public VirtualServiceSpecFluent.HttpNested<A> addNewHttp();
  public VirtualServiceSpecFluent.HttpNested<A> addNewHttpLike(HTTPRoute item);
  public VirtualServiceSpecFluent.HttpNested<A> setNewHttpLike(Integer index,HTTPRoute item);
  public VirtualServiceSpecFluent.HttpNested<A> editHttp(Integer index);
  public VirtualServiceSpecFluent.HttpNested<A> editFirstHttp();
  public VirtualServiceSpecFluent.HttpNested<A> editLastHttp();
  public VirtualServiceSpecFluent.HttpNested<A> editMatchingHttp(Predicate<HTTPRouteBuilder> predicate);
  public A addToTcp(Integer index,TCPRoute item);
  public A setToTcp(Integer index,TCPRoute item);
  public A addToTcp(io.fabric8.istio.api.networking.v1alpha3.TCPRoute... items);
  public A addAllToTcp(Collection<TCPRoute> items);
  public A removeFromTcp(io.fabric8.istio.api.networking.v1alpha3.TCPRoute... items);
  public A removeAllFromTcp(Collection<TCPRoute> items);
  public A removeMatchingFromTcp(Predicate<TCPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TCPRoute> getTcp();
  public List<TCPRoute> buildTcp();
  public TCPRoute buildTcp(Integer index);
  public TCPRoute buildFirstTcp();
  public TCPRoute buildLastTcp();
  public TCPRoute buildMatchingTcp(Predicate<TCPRouteBuilder> predicate);
  public Boolean hasMatchingTcp(Predicate<TCPRouteBuilder> predicate);
  public A withTcp(List<TCPRoute> tcp);
  public A withTcp(io.fabric8.istio.api.networking.v1alpha3.TCPRoute... tcp);
  public Boolean hasTcp();
  public VirtualServiceSpecFluent.TcpNested<A> addNewTcp();
  public VirtualServiceSpecFluent.TcpNested<A> addNewTcpLike(TCPRoute item);
  public VirtualServiceSpecFluent.TcpNested<A> setNewTcpLike(Integer index,TCPRoute item);
  public VirtualServiceSpecFluent.TcpNested<A> editTcp(Integer index);
  public VirtualServiceSpecFluent.TcpNested<A> editFirstTcp();
  public VirtualServiceSpecFluent.TcpNested<A> editLastTcp();
  public VirtualServiceSpecFluent.TcpNested<A> editMatchingTcp(Predicate<TCPRouteBuilder> predicate);
  public A addToTls(Integer index,TLSRoute item);
  public A setToTls(Integer index,TLSRoute item);
  public A addToTls(io.fabric8.istio.api.networking.v1alpha3.TLSRoute... items);
  public A addAllToTls(Collection<TLSRoute> items);
  public A removeFromTls(io.fabric8.istio.api.networking.v1alpha3.TLSRoute... items);
  public A removeAllFromTls(Collection<TLSRoute> items);
  public A removeMatchingFromTls(Predicate<TLSRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TLSRoute> getTls();
  public List<TLSRoute> buildTls();
  public TLSRoute buildTl(Integer index);
  public TLSRoute buildFirstTl();
  public TLSRoute buildLastTl();
  public TLSRoute buildMatchingTl(Predicate<TLSRouteBuilder> predicate);
  public Boolean hasMatchingTl(Predicate<TLSRouteBuilder> predicate);
  public A withTls(List<TLSRoute> tls);
  public A withTls(io.fabric8.istio.api.networking.v1alpha3.TLSRoute... tls);
  public Boolean hasTls();
  public VirtualServiceSpecFluent.TlsNested<A> addNewTl();
  public VirtualServiceSpecFluent.TlsNested<A> addNewTlLike(TLSRoute item);
  public VirtualServiceSpecFluent.TlsNested<A> setNewTlLike(Integer index,TLSRoute item);
  public VirtualServiceSpecFluent.TlsNested<A> editTl(Integer index);
  public VirtualServiceSpecFluent.TlsNested<A> editFirstTl();
  public VirtualServiceSpecFluent.TlsNested<A> editLastTl();
  public VirtualServiceSpecFluent.TlsNested<A> editMatchingTl(Predicate<TLSRouteBuilder> predicate);
  public interface HttpNested<N> extends Nested<N>,HTTPRouteFluent<VirtualServiceSpecFluent.HttpNested<N>>{
    public N and();
    public N endHttp();
    
  }
  public interface TcpNested<N> extends Nested<N>,TCPRouteFluent<VirtualServiceSpecFluent.TcpNested<N>>{
    public N and();
    public N endTcp();
    
  }
  public interface TlsNested<N> extends Nested<N>,TLSRouteFluent<VirtualServiceSpecFluent.TlsNested<N>>{
    public N and();
    public N endTl();
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/VirtualServiceSpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

 /**
  * Generated
  */
public interface VirtualServiceSpecFluent<A extends VirtualServiceSpecFluent<A>> extends Fluent<A>{
  public A addToExportTo(int index,String item);
  public A setToExportTo(int index,String item);
  public A addToExportTo(java.lang.String... items);
  public A addAllToExportTo(Collection<String> items);
  public A removeFromExportTo(java.lang.String... items);
  public A removeAllFromExportTo(Collection<String> items);
  public List<String> getExportTo();
  public String getExportTo(int index);
  public String getFirstExportTo();
  public String getLastExportTo();
  public String getMatchingExportTo(Predicate<String> predicate);
  public Boolean hasMatchingExportTo(Predicate<String> predicate);
  public A withExportTo(List<String> exportTo);
  public A withExportTo(java.lang.String... exportTo);
  public Boolean hasExportTo();
  public A addToGateways(int index,String item);
  public A setToGateways(int index,String item);
  public A addToGateways(java.lang.String... items);
  public A addAllToGateways(Collection<String> items);
  public A removeFromGateways(java.lang.String... items);
  public A removeAllFromGateways(Collection<String> items);
  public List<String> getGateways();
  public String getGateway(int index);
  public String getFirstGateway();
  public String getLastGateway();
  public String getMatchingGateway(Predicate<String> predicate);
  public Boolean hasMatchingGateway(Predicate<String> predicate);
  public A withGateways(List<String> gateways);
  public A withGateways(java.lang.String... gateways);
  public Boolean hasGateways();
  public A addToHosts(int index,String item);
  public A setToHosts(int index,String item);
  public A addToHosts(java.lang.String... items);
  public A addAllToHosts(Collection<String> items);
  public A removeFromHosts(java.lang.String... items);
  public A removeAllFromHosts(Collection<String> items);
  public List<String> getHosts();
  public String getHost(int index);
  public String getFirstHost();
  public String getLastHost();
  public String getMatchingHost(Predicate<String> predicate);
  public Boolean hasMatchingHost(Predicate<String> predicate);
  public A withHosts(List<String> hosts);
  public A withHosts(java.lang.String... hosts);
  public Boolean hasHosts();
  public A addToHttp(int index,HTTPRoute item);
  public A setToHttp(int index,HTTPRoute item);
  public A addToHttp(io.fabric8.istio.api.networking.v1alpha3.HTTPRoute... items);
  public A addAllToHttp(Collection<HTTPRoute> items);
  public A removeFromHttp(io.fabric8.istio.api.networking.v1alpha3.HTTPRoute... items);
  public A removeAllFromHttp(Collection<HTTPRoute> items);
  public A removeMatchingFromHttp(Predicate<HTTPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHttp instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRoute> getHttp();
  public List<HTTPRoute> buildHttp();
  public HTTPRoute buildHttp(int index);
  public HTTPRoute buildFirstHttp();
  public HTTPRoute buildLastHttp();
  public HTTPRoute buildMatchingHttp(Predicate<HTTPRouteBuilder> predicate);
  public Boolean hasMatchingHttp(Predicate<HTTPRouteBuilder> predicate);
  public A withHttp(List<HTTPRoute> http);
  public A withHttp(io.fabric8.istio.api.networking.v1alpha3.HTTPRoute... http);
  public Boolean hasHttp();
  public VirtualServiceSpecFluent.HttpNested<A> addNewHttp();
  public VirtualServiceSpecFluent.HttpNested<A> addNewHttpLike(HTTPRoute item);
  public VirtualServiceSpecFluent.HttpNested<A> setNewHttpLike(int index,HTTPRoute item);
  public VirtualServiceSpecFluent.HttpNested<A> editHttp(int index);
  public VirtualServiceSpecFluent.HttpNested<A> editFirstHttp();
  public VirtualServiceSpecFluent.HttpNested<A> editLastHttp();
  public VirtualServiceSpecFluent.HttpNested<A> editMatchingHttp(Predicate<HTTPRouteBuilder> predicate);
  public A addToTcp(int index,TCPRoute item);
  public A setToTcp(int index,TCPRoute item);
  public A addToTcp(io.fabric8.istio.api.networking.v1alpha3.TCPRoute... items);
  public A addAllToTcp(Collection<TCPRoute> items);
  public A removeFromTcp(io.fabric8.istio.api.networking.v1alpha3.TCPRoute... items);
  public A removeAllFromTcp(Collection<TCPRoute> items);
  public A removeMatchingFromTcp(Predicate<TCPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TCPRoute> getTcp();
  public List<TCPRoute> buildTcp();
  public TCPRoute buildTcp(int index);
  public TCPRoute buildFirstTcp();
  public TCPRoute buildLastTcp();
  public TCPRoute buildMatchingTcp(Predicate<TCPRouteBuilder> predicate);
  public Boolean hasMatchingTcp(Predicate<TCPRouteBuilder> predicate);
  public A withTcp(List<TCPRoute> tcp);
  public A withTcp(io.fabric8.istio.api.networking.v1alpha3.TCPRoute... tcp);
  public Boolean hasTcp();
  public VirtualServiceSpecFluent.TcpNested<A> addNewTcp();
  public VirtualServiceSpecFluent.TcpNested<A> addNewTcpLike(TCPRoute item);
  public VirtualServiceSpecFluent.TcpNested<A> setNewTcpLike(int index,TCPRoute item);
  public VirtualServiceSpecFluent.TcpNested<A> editTcp(int index);
  public VirtualServiceSpecFluent.TcpNested<A> editFirstTcp();
  public VirtualServiceSpecFluent.TcpNested<A> editLastTcp();
  public VirtualServiceSpecFluent.TcpNested<A> editMatchingTcp(Predicate<TCPRouteBuilder> predicate);
  public A addToTls(int index,TLSRoute item);
  public A setToTls(int index,TLSRoute item);
  public A addToTls(io.fabric8.istio.api.networking.v1alpha3.TLSRoute... items);
  public A addAllToTls(Collection<TLSRoute> items);
  public A removeFromTls(io.fabric8.istio.api.networking.v1alpha3.TLSRoute... items);
  public A removeAllFromTls(Collection<TLSRoute> items);
  public A removeMatchingFromTls(Predicate<TLSRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TLSRoute> getTls();
  public List<TLSRoute> buildTls();
  public TLSRoute buildTl(int index);
  public TLSRoute buildFirstTl();
  public TLSRoute buildLastTl();
  public TLSRoute buildMatchingTl(Predicate<TLSRouteBuilder> predicate);
  public Boolean hasMatchingTl(Predicate<TLSRouteBuilder> predicate);
  public A withTls(List<TLSRoute> tls);
  public A withTls(io.fabric8.istio.api.networking.v1alpha3.TLSRoute... tls);
  public Boolean hasTls();
  public VirtualServiceSpecFluent.TlsNested<A> addNewTl();
  public VirtualServiceSpecFluent.TlsNested<A> addNewTlLike(TLSRoute item);
  public VirtualServiceSpecFluent.TlsNested<A> setNewTlLike(int index,TLSRoute item);
  public VirtualServiceSpecFluent.TlsNested<A> editTl(int index);
  public VirtualServiceSpecFluent.TlsNested<A> editFirstTl();
  public VirtualServiceSpecFluent.TlsNested<A> editLastTl();
  public VirtualServiceSpecFluent.TlsNested<A> editMatchingTl(Predicate<TLSRouteBuilder> predicate);
  public interface HttpNested<N> extends Nested<N>,HTTPRouteFluent<VirtualServiceSpecFluent.HttpNested<N>>{
    public N and();
    public N endHttp();
    
  }
  public interface TcpNested<N> extends Nested<N>,TCPRouteFluent<VirtualServiceSpecFluent.TcpNested<N>>{
    public N and();
    public N endTcp();
    
  }
  public interface TlsNested<N> extends Nested<N>,TLSRouteFluent<VirtualServiceSpecFluent.TlsNested<N>>{
    public N and();
    public N endTl();
    
  }
  
}
